@@ -258,7 +258,7 @@ class Client(Callbacks, SocketHandler):
             "timestamp": int(timestamp() * 1000)
         })
 
-        response = requests.post(f"{self.api}/g/s/auth/register", data=data, headers=self.parse_headers(data=data), proxies=self.proxies, verify=self.certificatePath)
+        response = requests.post(f"{self.api}/g/s/auth/register", data=data, headers=headers.Headers(deviceId=deviceId).headers)
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
@@ -374,7 +374,7 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
-    def request_verify_code(self, email: str, resetPassword: bool = False):
+    def request_verify_code(self, email: str,dev: str,resetPassword: bool = False):
         """
         Request an verification code to the targeted email.
 
@@ -398,7 +398,7 @@ class Client(Callbacks, SocketHandler):
             data["purpose"] = "reset-password"
 
         data = json.dumps(data)
-        response = requests.post(f"{self.api}/g/s/auth/request-security-validation", headers=self.parse_headers(data=data), data=data, proxies=self.proxies, verify=self.certificatePath)
+        response = requests.post(f"{self.api}/g/s/auth/request-security-validation", headers=headers.Headers(deviceId=dev).headers)
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
